@@ -1,24 +1,26 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, Optional
+from typing import Any, List, Optional
 from ocp_resources.resource import Resource, MissingRequiredArgumentError
 
 
 class Group(Resource):
     """
-    Group represents a referenceable set of Users
+        Group represents a referenceable set of Users
+
+    Compatibility level 1: Stable within a major release for a minimum of 12 months or 3 minor releases (whichever is longer).
     """
 
     api_group: str = Resource.ApiGroup.USER_OPENSHIFT_IO
 
     def __init__(
         self,
-        users: Optional[Dict[str, Any]] = None,
+        users: Optional[List[Any]] = None,
         **kwargs: Any,
     ) -> None:
         """
         Args:
-            users(Dict[Any, Any]): Users is the list of users in this group.
+            users(List[Any]): Users is the list of users in this group.
 
         """
         super().__init__(**kwargs)
