@@ -63,7 +63,7 @@ class PersistentVolumeClaim(NamespacedResource):
         self.storage_class = storage_class
         self.pvlabel = pvlabel
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             self.res.update({
