@@ -29,13 +29,13 @@ class ServiceMeshMember(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.kind_dict and not self.yaml_file:
-            if not self.control_plane_ref:
-                raise MissingRequiredArgumentError(argument="self.control_plane_ref")
+        if not self.yaml_file:
+            if not all([
+                self.control_plane_ref,
+            ]):
+                raise MissingRequiredArgumentError(argument="control_plane_ref")
 
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
             _spec["controlPlaneRef"] = self.control_plane_ref
-
-    # End of generated code
